<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {
	// This gets the theme name from the stylesheet
	$themename = 'sunny_blue_sky';
	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'd5businessline'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	
	$options[] = array(
		'name' => 'Global', // tab title
		'type' => 'heading');
		
	$options[] = array(
		'desc' => '<span class="featured-area-title">Header</span>',
		'type' => 'info');
	
	$options[] = array(
		'name' => 'Logo',
		'desc' => 'Upload an image for the logo. PNG image is recommended.',
		'id' => 'logo',
		'std' => get_template_directory_uri() . '/images/logo.png',
		'type' => 'upload');
	
// Quotation	
	$options[] = array(
		'desc' => '<span class="featured-area-title">Bottom Quotation</span>',
		'type' => 'info');
	
	$options[] = array(
		'name' => 'Quote Text',
		'desc' => 'Input your Quotation here.',
		'id' => 'bottom-quotation',
		'std' => 'Cras tincidunt, magna pellentesque bibendum imperdiet, elit leo vulputate ante, vel scelerisque sem mi eget felis praesent ut massa id felis sodales adipiscing in eu odio aenean dui magna, lacinia eget mattis at, fringilla vitae mauris. ',
		'type' => 'textarea');

$options[] = array(
		'name' => 'Social',
		'type' => 'heading');

	$options[] = array(
		'desc' => '<span class="featured-area-title">Social Links</span>',
		'type' => 'info');
		
	$options[] = array(
		'name' => 'Facebook Link',
		'desc' => 'Input your Facebook URL here.',
		'id' => 'facebook-link',
		'std' => '',
		'type' => 'text');

	$options[] = array(
		'name' => 'Twitter Link',
		'desc' => 'Input your Twitter URL here.',
		'id' => 'twitter-link',
		'std' => '',
		'type' => 'text');
	
	$options[] = array(
		'name' => 'You Tube Channel Link',
		'desc' => 'Input your You Tube Channel URL here.',
		'id' => 'youtube-link',
		'std' => '',
		'type' => 'text');

	$options[] = array(
		'name' => 'flickr Link',
		'desc' => 'Input your flickr URL here.',
		'id' => 'flickr-link',
		'std' => '',
		'type' => 'text');

	$options[] = array(
		'name' => 'RSS Link', 
		'desc' => 'Input your RSS URL here.',
		'id' => 'rss-link',
		'std' => '',
		'type' => 'text');
	$options[] = array(
		'name' => 'Get PRO!',
		'type' => 'heading');
	
	$options[] = array(
		'desc' => 'Need more features and options? Try <a href="http://dinozoom.com/temalar" target="_blank"><b>Sunny Blue Sky PRO</b></a>.',
		'type' => 'info');
	return $options;
}

/*
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

	$('#example_showhidden').click(function() {
  		$('#section-example_text_hidden').fadeToggle(400);
	});

	if ($('#example_showhidden:checked').val() !== undefined) {
		$('#section-example_text_hidden').show();
	}

});
</script>

<?php
}